@@ -57,7 +57,8 @@ sudo zypper -nq install --force-resolution libxcb-cursor0 xcb-util-cursor-devel
 # qtwebengine
 sudo zypper -nq install alsa-devel dbus-1-devel libxkbfile-devel libdrm-devel \
          libXcomposite-devel libXcursor-devel libXrandr-devel libXtst-devel \
-         mozilla-nspr-devel mozilla-nss-devel glproto-devel libxshmfence-devel
+         mozilla-nspr-devel mozilla-nss-devel glproto-devel libxshmfence-devel \
+         vulkan-devel
 
 # qtwebkit
 sudo zypper -nq install libxml2-devel libxslt-devel
@@ -90,12 +91,23 @@ sudo zypper -nq update open-vm-tools
 # Tools to build Git
 sudo zypper -nq install autoconf libcurl-devel libexpat-devel
 
+# used for reading vcpkg packages version, from vcpkg.json
+sudo zypper -nq install jq
+
+# zip, needed for vcpkg caching
+sudo zypper -nq install zip
+
 # Nodejs - required by QtWebengine
-# Skip this and use commonly installed nodejs 18.16.0 version as it's available
-#sudo zypper -nq install nodejs16
+sudo zypper -nq install nodejs18
 
 # OpenSSL 3
 sudo zypper -nq install openssl-3
 
+# cifs-utils, for mounting smb drive
+sudo zypper -nq install cifs-utils
+
 gccVersion="$(gcc --version |grep gcc |cut -b 17-23)"
 echo "GCC = $gccVersion" >> versions.txt
+
+OpenSSLVersion="$(openssl-3 version |cut -b 9-14)"
+echo "System's OpenSSL = $OpenSSLVersion" >> ~/versions.txt
